py-seccure Changelog
====================

0.4.0 (2019-07-28)
------------------

- Use gmpy2 instead of gmpy


0.3.3 (2019-04-28)
------------------

- Bow to flake8
- py-seccure did not pad a signature with zeroes as seccure expected.
  This caused some signatures generated by py-seccure not being accepted
  by seccure. This has been fixed.  Old unpadded signatures are still
  accepted by py-seccure to keep backwards compatibility.
  See #16 (Thanks-to: Tanner Collin)
- Add support for Python 3.7
- Drop support for Python 2.6 & Python 3.3


0.3.2 (2016-08-07)
------------------

- Add ``generate_keypair``
- Fix doubling of affine points. #10 (Thanks-to: Joep Peeters)


0.3.1.3 (2016-01-03)
--------------------

- Small fix for Python 2.6


0.3.1.2 (2015-12-29)
--------------------

- Use static __version__ attribute.
- Use RST for README
